@@ -15,17 +15,17 @@ def main():
     """
 
     parser = argparse.ArgumentParser()
-    parser.add_argument("orbit", help="orbit center (gps,gnss,gps+glo, or specific centers) ", type=str)
+    parser.add_argument("orbit", help="orbit name (gps,gnss,gps+glo, or specific e.g. jax) ", type=str)
     parser.add_argument("year", help="year", type=int)
     parser.add_argument("month", help="month (or day of year)", type=int)
     parser.add_argument("day", help="day (zero if you use day of year earlier)", type=int)
-
     args = parser.parse_args()
 
 #   make sure environment variables exist.  set to current directory if not
     g.check_environ_variables()
 
-    orbit_list = ['igs', 'igs','jax','grg','wum','gbm','nav','gps','gps+glo','gnss']
+    orbit_list = ['igs', 'igr','jax','grg','wum','gbm','nav','gps','gps+glo','gnss']
+
 
 #   assign to normal variables
     pCtr = args.orbit
@@ -64,11 +64,14 @@ def main():
     if pCtr == 'nav':
         navname,navdir,foundit = g.getnavfile(year, month, day) 
         if foundit:
-            print('SUCCESS:', navname)
+            print('\n SUCCESS:', navdir+'/'+navname)
     else:
-        filename, fdir, foundit = g.getsp3file_mgex(year,month,day,pCtr)
+        if (pCtr == 'igs') or (pCtr == 'igr'):
+            filename, fdir, foundit = g.getsp3file_flex(year,month,day,pCtr)
+        else:
+            filename, fdir, foundit = g.getsp3file_mgex(year,month,day,pCtr)
         if foundit:
-            print('SUCCESS:', filename, fdir )
+            print('SUCCESS:', fdir+'/'+filename )
         else:
             print(filename , ' not found')
 
