@@ -19,6 +19,8 @@ def gnssir_guts(station,year,doy, snr_type, extension,lsp):
     my attempt to separate the inputs to the code and the guts of the code
     inputs are station name, year, day of year (integers)
     snr_type is an integer (99, 66, etc). lsp is a json
+
+    check to see if there were any results before sending a plot to the screen
     """
 
     #   make sure environment variables exist.  set to current directory if not
@@ -80,6 +82,7 @@ def gnssir_guts(station,year,doy, snr_type, extension,lsp):
         total_arcs = 0
         ct = 0
         for f in freqs:
+            found_results = False
             if plot_screen: 
                 # no idea if this will work
                 fig, (ax1, ax2) = plt.subplots(2, 1,figsize=(10,7))
@@ -91,7 +94,10 @@ def gnssir_guts(station,year,doy, snr_type, extension,lsp):
                 print('**** looking at frequency ', f, ' ReqAmp', reqAmp[ct], ' doy ', doy, 'ymd', year, month, day )
 #   get the list of satellites for this frequency
             if onesat == None:
-                satlist = g.find_satlist(f,snrE)
+                #satlist = g.find_satlist(f,snrE)
+                # added time dependent L2c and L5 satellite lists
+                satlist = g.find_satlist_wdate(f,snrE,year,doy)
+
             else:
                 satlist = onesat
                 if (int(satlist[0]) < 100) and (f > 100):
@@ -103,6 +109,7 @@ def gnssir_guts(station,year,doy, snr_type, extension,lsp):
                     x,y,Nv,cf,UTCtime,avgAzim,avgEdot,Edot2,delT= g.window_data(s1,s2,s5,s6,s7,s8,sat,ele,azi,t,edot,f,az1,az2,e1,e2,satNu,lsp['polyV'],lsp['pele'],screenstats) 
                     MJD = g.getMJD(year,month,day, UTCtime)
                     if Nv > minNumPts:
+                        found_results = True
                         #print('length of x', len(x))
                         maxF, maxAmp, eminObs, emaxObs,riseSet,px,pz= g.strip_compute(x,y,cf,maxH,lsp['desiredP'],lsp['polyV'],minH) 
                         nij =   pz[(px > NReg[0]) & (px < NReg[1])]
@@ -141,7 +148,8 @@ def gnssir_guts(station,year,doy, snr_type, extension,lsp):
 # close the output files
             ct += 1
             #'Yes' if fruit == 'Apple' else 'No'
-            if plot_screen: plot2screen(station, f, ax1, ax2,lsp['pltname']) 
+            if found_results and plot_screen:
+                plot2screen(station, f, ax1, ax2,lsp['pltname']) 
         fout.close() ; # these are the LSP results written to text file 
 
 
@@ -192,10 +200,10 @@ def plot2screen(station, f,ax1,ax2,pltname):
     #print(pltname)
     ax2.set_xlabel('Reflector Height (m)'); 
     #ax2.set_title('SNR periodogram')
-    ax2.set_ylabel('SNR periodogram')
+    ax2.set_ylabel('volts/volts')
     ax1.set_ylabel('volts/volts')
     ax1.set_xlabel('Elevation Angles (deg)')
-    ax1.set_title(station + ' SNR Data and Frequency L' + str(f))
+    ax1.set_title(station + ' SNR Data/' + g.ftitle(f) + ' Frequency')
     plt.show()
 
     return True
@@ -210,16 +218,16 @@ def read_json_file(station, extension):
     instructions_ext = str(os.environ['REFL_CODE']) + '/input/' + station + '.' + extension + '.json'
     instructions = str(os.environ['REFL_CODE']) + '/input/' + station + '.json'
     if os.path.isfile(instructions_ext):
-        print('using specific instructions for this extension')
+        #print('using specific instructions for this extension')
         with open(instructions_ext) as f:
             lsp = json.load(f)
     else:
-        print('will use the default instruction file')
+        #print('will use the default instruction file')
         if os.path.isfile(instructions):
             with open(instructions) as f:
                 lsp = json.load(f)
         else:
-            print('json instruction file does not exist: ', instructions)
+            print('The json instruction file does not exist: ', instructions)
             print('Please make with make_json_input and run this code again.')
             sys.exit()
 
