@@ -118,9 +118,12 @@ def main():
     f=freqs[0]
     NReg = [h1, h2] # noise region - again, this is for typical snow setup
 
-
-    quick.quickLook_function(station, year, doy, snr,f,e1,e2,h1,h2,reqAmp,pele,sat,PkNoise,fortran)
-
+    pltscreen = True
+    # Kelly for jupyter notebooks set this to false
+    #pltscreen = False
+    data,datakey = quick.quickLook_function(station, year, doy, snr, f, e1,e2,h1,h2,reqAmp,pele,sat,PkNoise,fortran,pltscreen)
+    # the key is saved wth the same keys as the data dictionary, in this order 
+    # [avgAzim, RH, satNumber,frequency,maxAmplitude,Peak2Noise, UTChour]
 
 if __name__ == "__main__":
     main()
