@@ -1,4 +1,6 @@
 """
+author: kristine larson
+called by quickLook_cl.py
 quickLook functions - consolidated snr reader (previously in a separate file)
 """
 import sys
@@ -34,6 +36,7 @@ def read_snr_simple(obsfile):
         #print('read_snr_simple, Number of rows:', r, ' Number of columns:',c)
         sat = f[:,0]; ele = f[:,1]; azi = f[:,2]; t =  f[:,3]
         edot =  f[:,4]; s1 = f[:,6]; s2 = f[:,7]; s6 = f[:,5]
+        # 
         s1 = np.power(10,(s1/20))  
         s2 = np.power(10,(s2/20))  
         s6 = s6/20; s6 = np.power(10,s6)  
@@ -43,7 +46,7 @@ def read_snr_simple(obsfile):
             s5 = f[:,8]
             if (sum(s5) > 0):
                 s5 = s5/20; s5 = np.power(10,s5)  
-            print(len(s5))
+            #print(len(s5))
         if c > 9:
             s7 = f[:,9]
             if (sum(s7) > 0):
@@ -72,7 +75,7 @@ def read_snr_simple(obsfile):
     return allGood, sat, ele, azi, t, edot, s1, s2, s5, s6, s7, s8, snrE
 
 
-def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pele,satsel,PkNoise,fortran):
+def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pele,satsel,PkNoise,fortran,pltscreen):
     """
     inputs:
     station name (4 char), year, day of year
@@ -84,10 +87,22 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
     pele is the elevation angle limits for the polynomial removal.  units: degrees
     KL 20may10 pk2noise value is now sent from main function, which can be set online
     KL 20aug07 added fortran boolean
+    KL 21feb06 return data from the plots so that Jupyter notebooks can use them.
+    also added pltscreen variable so that the default plots are not always displayed
+    KL 21mar25 added datakey dictionaries for the Jupyter notebook people
+    KL 21apr02 added error checking on whether requested datastreams exist. no data, no analysis
     """
+
+    # dictionary for output
+    data = {'NW':{},'SW':{},'NE':{},'SE':{},'fNW':{},'fSW':{},'fNE':{},'fSE': {} }
+
+    # dictionary for key
+    datakey = {'NW':{},'SW':{},'NE':{},'SE':{},'fNW':{},'fSW':{},'fNE':{},'fSE': {} }
+
     # make sure environment variables exist
     g.check_environ_variables()
 
+    # make sure logs directory exists
     if not os.path.isdir('logs'):
         subprocess.call(['mkdir', 'logs'])
 
@@ -96,6 +111,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
     ann = g.make_nav_dirs(year)
     # titles in 4 quadrants - for webApp
     titles = ['Northwest', 'Southwest','Northeast', 'Southeast']
+    stitles = ['NW', 'SW','NE', 'SE']
     # define where the axes are located
     bx = [0,1,0,1]; by = [0,0,1,1]; bz = [1,3,2,4]
 
@@ -111,6 +127,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
     #print('Refl. Ht. Noise Region used: ', NReg)
     # for quickLook, we use the four geographic quadrants - these are azimuth angles in degrees
     azval = [270, 360, 180, 270, 0, 90, 90, 180]
+    # try adding 5 degrees at the quadrant edges, except for north
     naz = int(len(azval)/2) # number of azimuth pairs
     pltname = 'temp.png' # default plot
     requireAmp = reqAmp[0]
@@ -134,40 +151,49 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
                 print('This code used to try and make one for you, but I have removed this option.')
                 print('Please us rinex2snr and make a SNR file')
                 sys.exit()
-                #print('I will try to pick up a RINEX file ')
-                #print('and translate it for you. This will be GPS only.')
-                #print('For now I will check all the official archives for you.')
-                #rate = 'low'; dec_rate = 0; archive = 'all'; 
-                #rinex.conv2snr(year, doy, station, int(snr_type), 'nav',rate,dec_rate,archive,fortran)
-                #if os.path.isfile(obsfile):
-                #    print('the SNR file now exists')  
-                #else:
-                #    print('the RINEX file did not exist, had no SNR data, or failed to convert, so exiting.')
     allGood,sat,ele,azi,t,edot,s1,s2,s5,s6,s7,s8,snrE = read_snr_simple(obsfile)
     if allGood == 1:
         # make output file for the quickLook RRH values, just so you can give them a quick look see
-        rhout = open('logs/rh.txt','w+')
+        quicklog = 'logs/rh_' + station + '.txt'
+        rhout = open(quicklog,'w+')
         amax = 0
         minEdataset = np.min(ele)
+        sats = sat 
+        # very rare that no GPS data exist, so will not check it.  I will probably regret this
+        #if (f < 6):
+        #    b = sats[(sats<100)]; print('gps',len(b))
+        if (f > 100) and (f < 200): # glonass
+            b = sats[(sats>100) & (sats<200)]; # print('glonass',len(b))
+            if len(b) == 0:
+                print('NO Glonass DATA') ; 
+                return data, datakey
+        elif (f > 200) & (f < 300): # galileo
+            b = sats[(sats>200) & (sats<300)]; # print('galileo',len(b))
+            if len(b) == 0:
+                print('NO Galileo data'); 
+                return data, datakey
+        elif (f > 300): # beidou
+            b = sats[(sats>300) & (sats<400)]; # print('beidou',len(b))
+            if len(b) == 0:
+                print('NO Beidou data'); 
+                return data, datakey
+
         print('minimum elevation angle (degrees) for this dataset: ', minEdataset)
         if minEdataset > (e1+0.5):
             print('It looks like the receiver had an elevation mask')
             e1 = minEdataset
-        if webapp:
-            fig = Figure(figsize=(10,6), dpi=120)
-            axes = fig.subplots(2, 2)
-        else:
-            #plt.figure()
-            # trying to help Kelly
+        if pltscreen:
             plt.figure(figsize=(10,6))
         for a in range(naz):
-            if not webapp:
+            if pltscreen:
                 plt.subplot(2,2,bz[a])
                 plt.title(titles[a])
             az1 = azval[(a*2)] ; az2 = azval[(a*2 + 1)]
             # this means no satellite list was given, so get them all
             if satsel == None:
-                satlist = g.find_satlist(f,snrE)
+                #satlist = g.find_satlist(f,snrE)
+                #march 29, 2021 made l2c and l5 time dependent
+                satlist = g.find_satlist_wdate(f,snrE,year,doy)
             else:
                 satlist = [satsel]
 
@@ -184,30 +210,116 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
                         Noise = 1; iAzim = 0 # made up numbers
                     if (delT < delTmax) & (eminObs < (e1 + ediff)) & (emaxObs > (e2 - ediff)) & (maxAmp > requireAmp) & (maxAmp/Noise > PkNoise):
                         T = g.nicerTime(UTCtime)
-                        rhout.write('SUCCESS Azimuth {0:3.0f} RH {1:6.3f} m, Sat {2:3.0f} Freq {3:3.0f} Amp {4:4.1f} PkNoise {5:3.1f} UTC {6:5s} \n '.format( 
-                            avgAzim,maxF,satNu,f,maxAmp,maxAmp/Noise,T))
-                        if not webapp:
+                        # az, RH, sat, amp, peak2noise, Time
+                        rhout.write('{0:3.0f} {1:6.3f} {2:3.0f} {3:4.1f} {4:3.1f} {5:6.2f} {6:2.0f} \n '.format(iAzim,maxF,satNu,maxAmp,maxAmp/Noise,UTCtime,1))
+                        if pltscreen:
                             plt.plot(px,pz,linewidth=1.5)
-                        else:
-                            axes[bx[a],by[a]].plot(px,pz,linewidth=2)
-                            axes[bx[a],by[a]].set_title(titles[a])
+                        idc = stitles[a]
+                        data[idc][satNu] = [px,pz]
+                        datakey[idc][satNu] = [avgAzim, maxF, satNu,f,maxAmp,maxAmp/Noise, UTCtime]
+
                     else:
-                        if not webapp:
+                        # these are failed tracks
+                        if pltscreen:
                             plt.plot(px,pz,'gray',linewidth=0.5)
+                        idc = 'f' + stitles[a]
+                        data[idc][satNu] = [px,pz]
+                        datakey[idc][satNu] = [avgAzim, maxF, satNu,f,maxAmp,maxAmp/Noise, UTCtime]
+                        rhout.write('{0:3.0f} {1:6.3f} {2:3.0f} {3:4.1f} {4:3.1f} {5:6.2f} {6:2.0f} \n '.format(iAzim,maxF,satNu,maxAmp,maxAmp/Noise,UTCtime,-1))
 
             # i do not know how to add a grid using these version of matplotlib
-            tt = 'GNSS-IR results: ' + station.upper() + ' Freq:' + str(f) + ' ' + str(year) + '/' + str(doy)
-            aaa, bbb = plt.ylim()
-            amax = max(amax,  bbb) # do not know how to implement this ...
-            if (a == 3) or (a==1):
-                plt.xlabel('reflector height (m)')
-        plt.suptitle(tt, fontsize=12)
+            tt = 'GNSS-IR results: ' + station.upper() + ' Freq:' + g.ftitle(f) + ' Year/DOY:' + str(year) + ',' + str(doy)
+            if pltscreen:
+                aaa, bbb = plt.ylim()
+                # see if this works
+                plt.grid()
+                amax = max(amax,  bbb) # do not know how to implement this ...
+                if (a == 3) or (a==1):
+                    plt.xlabel('reflector height (m)')
+                if (a == 1) or (a==0):
+                    plt.ylabel('volts/volts')
 
         rhout.close()
-        print('Reflector Height results are stored in a file called logs/rh.txt')
-        if webapp:
-            fig.savefig('temp.png', format="png")
-        else:
+        #print('preliminary reflector height results are stored in a file called logs/rh.txt')
+        # this file seems to have an empty line at the end.  i do not know why.
+
+
+        if pltscreen:
+            plt.suptitle(tt, fontsize=12)
+            # sure - throw in another plot
+            goodbad(quicklog,station,minH,maxH,PkNoise,reqAmp,f)
             plt.show()
+          
     else: 
         print('some kind of problem with SNR file, so I am exiting the code politely.')
+
+
+    # returns multidimensional dictionary of lomb scargle results so 
+    # that the jupyter notebook people can replot them
+    # 21mar26 added a key
+    return data,datakey
+
+def goodbad(fname,station,h1,h2,PkNoise,reqAmp,freq):
+    """
+    simple visualizer of "good" and "bad" azimuths
+    input is a filename, the station name, and the min and max RH
+    and the peak to noise, required amplitude criteria, and frequency used
+    should not even call this code if there are no data.  need to fix this
+    author: kristine larson
+    """
+    try:
+        a = np.loadtxt(fname,comments='%')
+    except:
+        print('no results in the file')
+
+    if len(a) == 0:
+        return
+
+    ij = (a[:,6] == 1) # good retrievals
+    ik = (a[:,6] == -1) # bad retrievals
+    fs = 12
+    plt.figure(figsize=(10,6))
+    plt.subplot(3,1,1)
+    plt.plot(a[ij,0], a[ij,1], 'o',color='blue',label='good')
+    plt.plot(a[ik,0], a[ik,1], 'o',color='gray', label='bad')
+    plt.title('quickLook Retrieval Metrics: ' + station + ' ' + g.ftitle(freq))
+    plt.legend(loc="upper right")
+    plt.ylabel('Reflector Height (m)')
+    plt.grid()
+    plt.xlim((0, 360))
+    plt.ylim((h1, h2))
+    ax = plt.gca()
+    ax.axes.xaxis.set_ticklabels([])
+
+
+    plt.subplot(3,1,2)
+    plt.plot([0, 360], [PkNoise, PkNoise], 'k--',label='QC value used')
+    plt.plot(a[ij,0], a[ij,4], 'o',color='blue')
+    plt.plot(a[ik,0], a[ik,4], 'o',color='gray')
+    plt.legend(loc="upper right")
+    plt.ylabel('peak2noise')
+    plt.grid()
+    plt.xlim((0, 360))
+    ax = plt.gca()
+    ax.axes.xaxis.set_ticklabels([])
+
+    plt.subplot(3,1,3)
+    plt.plot([0, 360], [reqAmp, reqAmp], 'k--',label='QC value used')
+    plt.plot(a[ij,0], a[ij,3], 'o',color='blue')
+    plt.plot(a[ik,0], a[ik,3], 'o',color='gray') 
+    plt.legend(loc="upper right")
+    plt.ylabel('Spectral Peak Amplitude')
+    plt.xlabel('Azimuth (degrees)')
+    plt.grid()
+    plt.xlim((0, 360))
+
+# old code
+#print('I will try to pick up a RINEX file ')
+#print('and translate it for you. This will be GPS only.')
+#print('For now I will check all the official archives for you.')
+#rate = 'low'; dec_rate = 0; archive = 'all'; 
+#rinex.conv2snr(year, doy, station, int(snr_type), 'nav',rate,dec_rate,archive,fortran)
+#if os.path.isfile(obsfile):
+#    print('the SNR file now exists')  
+#else:
+#    print('the RINEX file did not exist, had no SNR data, or failed to convert, so exiting.')
