@@ -3,15 +3,19 @@
 command line tool for the rinex2snr module
 pretty much what it sounds like - it translates rinex files and makes SNR files
 kristine larson
+
+compile the fortran first
+f2py -c -m gnssrefl.gpssnr gnssrefl/gpssnr.f
 """
 
 import argparse
 import datetime
+import numpy as np
 import os
 import sys
 import subprocess
+import time
 
-import numpy as np
 
 import gnssrefl.gps as g
 import gnssrefl.rinex2snr as rnx
@@ -30,10 +34,12 @@ def main():
     parser.add_argument("-dec", default=0, type=int, help="decimate (seconds)")
     parser.add_argument("-nolook", default='False', metavar='False', type=str, help="True means only use RINEX files on local machine")
     parser.add_argument("-fortran", default='True', metavar='True',type=str, help="True means use Fortran RINEX translators ")
-    parser.add_argument("-archive", default=None, metavar='all',help="archive (unavco,sopac,cddis,sonel,nz,ga,ngs,bkg,nrcan)", type=str)
+    parser.add_argument("-archive", default=None, metavar='all',help="specify one archive: unavco,sopac,cddis,sonel,nz,ga,ngs,bkg,nrcan", type=str)
     parser.add_argument("-doy_end", default=None, help="end day of year", type=int)
     parser.add_argument("-year_end", default=None, help="end year", type=int)
     parser.add_argument("-overwrite", default=None, help="boolean", type=str)
+    parser.add_argument("-translator", default=None, help="translator(fortran,hybrid,python)", type=str)
+    parser.add_argument("-srate", default=None, help="sample rate (RINEX 3 only)", type=int)
 
     args = parser.parse_args()
 #   make sure environment variables exist.  set to current directory if not
@@ -55,10 +61,6 @@ def main():
         print('Year must be four characters long. Exiting.', year)
         sys.exit()
 
-    if args.fortran == 'True':
-        fortran = True
-    else:
-        fortran = False
 
     doy= args.doy
     isnr = args.snr # defined as an integer
@@ -86,6 +88,10 @@ def main():
 
 
 
+    if args.fortran == 'True':
+        fortran = True
+    else:
+        fortran = False
 
     # check that the fortran exe exist
     if fortran:
@@ -94,15 +100,17 @@ def main():
             if not os.path.isfile(snrexe):
                 print('You have selected the fortran and GPS only options.')
                 print('However, the fortran translator gpsSNR.e has not been properly installed.')
-                print('We are changing to the non-fortran option.')
+                print('We are changing to the hybrid translator option.')
                 fortran = False
+                translator = 'hybrid'
         else:
             snrexe = g.gnssSNR_version()
             if not os.path.isfile(snrexe):
                 print('You have selected the fortran and GNSS options.')
                 print('However, the fortran translator gnssSNR.e has not been properly installed.')
-                print('We are changing to the non-fortran option.')
+                print('We are changing to the python translator option (the hybrid is not yet working).')
                 fortran = False
+                translator = 'python'
 
 
 # if true ony use local RINEX files, which speeds up analysis of local datasets
@@ -122,7 +130,7 @@ def main():
 
 
 # currently allowed archives 
-    archive_list = ['sopac', 'unavco','sonel','cddis','nz','ga','bkg','jeff','ngs','nrcan']
+    archive_list = ['sopac', 'unavco','sonel','cddis','nz','ga','bkg','jeff','ngs','nrcan','special']
     if args.archive == None:
         archive = 'all'
     else:
@@ -149,9 +157,43 @@ def main():
     overwrite = False
     if (args.overwrite == 'True'):
         overwrite = True
-    print('Feedback is written to files in the subdirectory logs/')
-    rnx.run_rinex2snr(station, year_list, doy_list, isnr, orb, rate,dec_rate,archive,fortran,nol,overwrite)
+
+    # default is to use hybrid for RINEX translator
+    if args.translator == None:
+        translator = 'hybrid'
+    else:
+        translator = args.translator
+        if translator == 'hybrid':
+            fortran = False # override
+        if translator == 'python':
+            fortran = False # override - but this is sllllllooooowwww
+
+    # this is for RINEX 3 only - default will be 30
+    if args.srate == None:
+        srate = 30
+    else:
+        srate = args.srate
+
+
+    rnx.run_rinex2snr(station, year_list, doy_list, isnr, orb, rate,dec_rate,archive,fortran,nol,overwrite,translator,srate)
+    print('Feedback written to subdirectory logs')
 
 
 if __name__ == "__main__":
     main()
+
+
+
+
+#    if translator == 'hybrid':
+#        snrexe = g.gnssSNR_version()
+#        if (orb == 'jax') or (orb == 'gbm') or (orb=='igr'):
+#            print('The hybrid option does not currently work on multi-GNSS files')
+#            print('I am currently testing this option')
+#           if not os.path.isfile(snrexe):
+#                print('setting to python in the interim')
+                #translator = 'python'
+    #        else:
+    #            print('setting to fortran in the interim')
+    #            translator = 'fortran'
+
